@@ -30,13 +30,13 @@
 ##' For random effect models a generalized delta-method is used. First
 ##' the joint covariance of random effect and parameter estimation error is approximated
 ##' by
-##' \deqn{V \pmatrix{ \hat u - u \cr \hat\theta - \theta } \approx
-##' \pmatrix{ H_{uu}^{-1} & 0 \cr 0 & 0 } +
+##' \deqn{V \left( \begin{array}{cc} \hat u - u \cr \hat\theta - \theta \end{array} \right) \approx
+##' \left( \begin{array}{cc} H_{uu}^{-1} & 0 \cr 0 & 0 \end{array} \right) +
 ##' J V(\hat\theta) J'
 ##' }
 ##' where \eqn{H_{uu}} denotes random effect block of the full joint
 ##' Hessian of \code{obj$env$f} and \eqn{J} denotes the Jacobian of
-##' \eqn{\pmatrix{\hat u(\theta) \cr \theta}} wrt. \eqn{\theta}.
+##' \eqn{\left( \begin{array}{cc}\hat u(\theta) \cr \theta \end{array} \right)} wrt. \eqn{\theta}.
 ##' Here, the first term represents the expected conditional variance
 ##' of the estimation error given the data and the second term represents the variance
 ##' of the conditional mean of the estimation error given the data.
@@ -44,13 +44,13 @@
 ##' Now the delta method can be applied on a general non-linear
 ##' function \eqn{\phi(u,\theta)} of random effects \eqn{u} and
 ##' parameters \eqn{\theta}:
-##' \deqn{V\left(\phi(\hat u,\hat\theta) - \phi(u,\theta) \right)\approx \nabla\phi V \pmatrix{
-##' \hat u - u \cr \hat\theta - \theta }\nabla\phi'}
+##' \deqn{V\left(\phi(\hat u,\hat\theta) - \phi(u,\theta) \right)\approx \nabla\phi V \left( \begin{array}{cc}
+##' \hat u - u \cr \hat\theta - \theta \end{array} \right) \nabla\phi'}
 ##'
 ##' The full joint covariance is not returned by default, because it
 ##' may require large amounts of memory.  It may be obtained by
 ##' specifying \code{getJointPrecision=TRUE}, in which case \eqn{V
-##' \pmatrix{ \hat u - u \cr \hat\theta - \theta } ^{-1} } will be part of the
+##' \left( \begin{array}{cc} \hat u - u \cr \hat\theta - \theta \end{array} \right) ^{-1} } will be part of the
 ##' output. This matrix must be manually inverted using
 ##' \code{solve(jointPrecision)} in order to get the joint covariance
 ##' matrix. Note, that the parameter order will follow the original
@@ -255,7 +255,7 @@ sdreport <- function(obj,par.fixed=NULL,hessian.fixed=NULL,getJointPrecision=FAL
               cov.fixed=Vtheta,pdHess=pdHess,
               gradient.fixed=gradient.fixed)
   ## ======== Calculate bias corrected random effects estimates if requested
-  if(bias.correct){
+  if(bias.correct && !is.null(r)) {
       epsilon <- rep(0,length(phi))
       names(epsilon) <- names(phi)
       parameters <- obj$env$parameters
@@ -330,6 +330,11 @@ sdreport <- function(obj,par.fixed=NULL,hessian.fixed=NULL,getJointPrecision=FAL
           }
       }
   }
+  ## ======== bias correct but no random effects => nothing to do
+  if(bias.correct && is.null(r)) {
+      ans$unbiased <- list(value=ans$value, sd=ans$sd, cov=ans$cov)
+      warning("'bias.correct' does nothing without random effects")
+  }
   ## ======== Find marginal variances of all random effects i.e. phi(u,theta)=u
   if(!is.null(r)){
     if(is(L,"dCHMsuper")){ ## Required by inverse subset algorithm
@@ -345,7 +350,11 @@ sdreport <- function(obj,par.fixed=NULL,hessian.fixed=NULL,getJointPrecision=FAL
               f(par, order = 1, type = "ADGrad", rangeweight = w, doforward=0)[r]
           }
           nonr <- setdiff(seq_along(par), r)
-          tmp <- sapply(nonr,reverse.sweep)
+          framework <- .Call("getFramework", PACKAGE=obj$env$DLL)
+          if (framework != "TMBad")
+              tmp <- sapply(nonr,reverse.sweep)
+          else
+              tmp <- f(par, order = 1, type = "ADGrad", keepx=nonr, keepy=r) ## TMBad only !!!
           if(!is.matrix(tmp)) ## Happens if length(r)==1
               tmp <- matrix(tmp, ncol=length(nonr) )
           A <- solve(hessian.random, tmp)
